@@ -1,7 +1,7 @@
 package Module::FatPack;
 
 our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -126,9 +126,9 @@ sub fatpack_modules {
     my %args = @_;
 
     my $pm = $args{pm};
-    my $line_prefix = $args{line_prefix} // $pm ? '#':'  ';
-    my $add_begin_block = $args{add_begin_block} // $pm ? 0:1;
-    my $put_hook_at_the_end = $args{put_hook_at_the_end} // $pm ? 1:0;
+    my $line_prefix = $args{line_prefix} // ($pm ? '#':'  ');
+    my $add_begin_block = $args{add_begin_block} // ($pm ? 0:1);
+    my $put_hook_at_the_end = $args{put_hook_at_the_end} // ($pm ? 1:0);
 
     my %module_srcs; # key: mod_pm
     my %fatpack_keys;
@@ -273,7 +273,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.12 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-27.
+This document describes version 0.13 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-27.
 
 =head1 FUNCTIONS
 
